"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FoldType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _FoldTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FoldType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FoldTypeZero: _FoldType.ValueType  # 0
    """占位"""

    FoldTypePublish: _FoldType.ValueType  # 1
    """用户发布折叠"""

    FoldTypeFrequent: _FoldType.ValueType  # 2
    """转发超频折叠"""

    FoldTypeUnite: _FoldType.ValueType  # 3
    """联合投稿折叠"""

    FoldTypeLimit: _FoldType.ValueType  # 4
    """动态受限折叠"""

class FoldType(_FoldType, metaclass=_FoldTypeEnumTypeWrapper):
    """折叠分类"""
    pass

FoldTypeZero: FoldType.ValueType  # 0
"""占位"""

FoldTypePublish: FoldType.ValueType  # 1
"""用户发布折叠"""

FoldTypeFrequent: FoldType.ValueType  # 2
"""转发超频折叠"""

FoldTypeUnite: FoldType.ValueType  # 3
"""联合投稿折叠"""

FoldTypeLimit: FoldType.ValueType  # 4
"""动态受限折叠"""

global___FoldType = FoldType


class _VideoSubType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _VideoSubTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoSubType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VideoSubTypeNone: _VideoSubType.ValueType  # 0
    """没有子类型"""

    VideoSubTypeBangumi: _VideoSubType.ValueType  # 1
    """番剧"""

    VideoSubTypeMovie: _VideoSubType.ValueType  # 2
    """电影"""

    VideoSubTypeDocumentary: _VideoSubType.ValueType  # 3
    """纪录片"""

    VideoSubTypeDomestic: _VideoSubType.ValueType  # 4
    """国创"""

    VideoSubTypeTeleplay: _VideoSubType.ValueType  # 5
    """电视剧"""

class VideoSubType(_VideoSubType, metaclass=_VideoSubTypeEnumTypeWrapper):
    """番剧类型"""
    pass

VideoSubTypeNone: VideoSubType.ValueType  # 0
"""没有子类型"""

VideoSubTypeBangumi: VideoSubType.ValueType  # 1
"""番剧"""

VideoSubTypeMovie: VideoSubType.ValueType  # 2
"""电影"""

VideoSubTypeDocumentary: VideoSubType.ValueType  # 3
"""纪录片"""

VideoSubTypeDomestic: VideoSubType.ValueType  # 4
"""国创"""

VideoSubTypeTeleplay: VideoSubType.ValueType  # 5
"""电视剧"""

global___VideoSubType = VideoSubType


class _MediaType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _MediaTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MediaType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MediaTypeNone: _MediaType.ValueType  # 0
    """本地"""

    MediaTypeUGC: _MediaType.ValueType  # 1
    """UGC"""

    MediaTypePGC: _MediaType.ValueType  # 2
    """PGC"""

    MediaTypeLive: _MediaType.ValueType  # 3
    """直播"""

    MediaTypeVCS: _MediaType.ValueType  # 4
    """小视频"""

class MediaType(_MediaType, metaclass=_MediaTypeEnumTypeWrapper):
    """播放器类型"""
    pass

MediaTypeNone: MediaType.ValueType  # 0
"""本地"""

MediaTypeUGC: MediaType.ValueType  # 1
"""UGC"""

MediaTypePGC: MediaType.ValueType  # 2
"""PGC"""

MediaTypeLive: MediaType.ValueType  # 3
"""直播"""

MediaTypeVCS: MediaType.ValueType  # 4
"""小视频"""

global___MediaType = MediaType


class _SVideoType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _SVideoTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SVideoType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TypeNone: _SVideoType.ValueType  # 0
    """无类型"""

    TypeDynamic: _SVideoType.ValueType  # 1
    """动态"""

    TypePopularIndex: _SVideoType.ValueType  # 2
    """热门分类"""

    TypePopularHotword: _SVideoType.ValueType  # 3
    """热点聚合"""

class SVideoType(_SVideoType, metaclass=_SVideoTypeEnumTypeWrapper):
    """入口联播页类型"""
    pass

TypeNone: SVideoType.ValueType  # 0
"""无类型"""

TypeDynamic: SVideoType.ValueType  # 1
"""动态"""

TypePopularIndex: SVideoType.ValueType  # 2
"""热门分类"""

TypePopularHotword: SVideoType.ValueType  # 3
"""热点聚合"""

global___SVideoType = SVideoType


class _RelationStatus:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _RelationStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RelationStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    relation_status_none: _RelationStatus.ValueType  # 0
    relation_status_nofollow: _RelationStatus.ValueType  # 1
    """未关注"""

    relation_status_follow: _RelationStatus.ValueType  # 2
    """关注"""

    relation_status_followed: _RelationStatus.ValueType  # 3
    """被关注"""

    relation_status_mutual_concern: _RelationStatus.ValueType  # 4
    """互相关注"""

    relation_status_special: _RelationStatus.ValueType  # 5
    """特别关注"""

class RelationStatus(_RelationStatus, metaclass=_RelationStatusEnumTypeWrapper):
    """关注状态"""
    pass

relation_status_none: RelationStatus.ValueType  # 0
relation_status_nofollow: RelationStatus.ValueType  # 1
"""未关注"""

relation_status_follow: RelationStatus.ValueType  # 2
"""关注"""

relation_status_followed: RelationStatus.ValueType  # 3
"""被关注"""

relation_status_mutual_concern: RelationStatus.ValueType  # 4
"""互相关注"""

relation_status_special: RelationStatus.ValueType  # 5
"""特别关注"""

global___RelationStatus = RelationStatus


class NoReq(google.protobuf.message.Message):
    """空请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___NoReq = NoReq

class NoReply(google.protobuf.message.Message):
    """空响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___NoReply = NoReply

class DynVideoReq(google.protobuf.message.Message):
    """动态视频页-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    UPDATE_BASELINE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    REFRESH_TYPE_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    teenagers_mode: builtins.int
    """青少年模式"""

    update_baseline: typing.Text
    """透传 update_baseline"""

    offset: typing.Text
    """透传 history_offset"""

    page: builtins.int
    """向下翻页数"""

    refresh_type: builtins.int
    """刷新方式
    1:向上刷新 2:向下翻页
    """

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """流版本"""

    fnval: builtins.int
    """流类型"""

    force_host: builtins.int
    """是否强制使用域名"""

    fourk: builtins.int
    """是否4K"""

    def __init__(self,
        *,
        teenagers_mode: builtins.int = ...,
        update_baseline: typing.Text = ...,
        offset: typing.Text = ...,
        page: builtins.int = ...,
        refresh_type: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","offset",b"offset","page",b"page","qn",b"qn","refresh_type",b"refresh_type","teenagers_mode",b"teenagers_mode","update_baseline",b"update_baseline"]) -> None: ...
global___DynVideoReq = DynVideoReq

class DynVideoReqReply(google.protobuf.message.Message):
    """动态视频页-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIST_FIELD_NUMBER: builtins.int
    UPDATE_NUM_FIELD_NUMBER: builtins.int
    HISTORY_OFFSET_FIELD_NUMBER: builtins.int
    UPDATE_BASELINE_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
        pass
    update_num: builtins.int
    """更新的动态数"""

    history_offset: typing.Text
    """历史偏移"""

    update_baseline: typing.Text
    """更新基础信息"""

    has_more: builtins.int
    """是否还有更多数据"""

    def __init__(self,
        *,
        list: typing.Optional[typing.Iterable[global___DynamicItem]] = ...,
        update_num: builtins.int = ...,
        history_offset: typing.Text = ...,
        update_baseline: typing.Text = ...,
        has_more: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more",b"has_more","history_offset",b"history_offset","list",b"list","update_baseline",b"update_baseline","update_num",b"update_num"]) -> None: ...
global___DynVideoReqReply = DynVideoReqReply

class DynamicItem(google.protobuf.message.Message):
    """动态卡片项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CARD_TYPE_FIELD_NUMBER: builtins.int
    ITEM_TYPE_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    DYN_ID_STR_FIELD_NUMBER: builtins.int
    ORIG_DYN_ID_STR_FIELD_NUMBER: builtins.int
    R_TYPE_FIELD_NUMBER: builtins.int
    HAS_FOLD_FIELD_NUMBER: builtins.int
    card_type: typing.Text
    """卡片类型
    forward:转发 av:稿件视频 fold:折叠 pgc:pgc内容 courses:付费视频 upList:最近访问列表 followList:我的追番列表
    """

    item_type: typing.Text
    """转发类型下，items的类型"""

    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Module]:
        """模块内容"""
        pass
    dyn_id_str: typing.Text
    """动态ID str"""

    orig_dyn_id_str: typing.Text
    """转发动态ID str"""

    r_type: builtins.int
    """r_type"""

    has_fold: builtins.int
    """该卡片下面是否含有折叠卡"""

    def __init__(self,
        *,
        card_type: typing.Text = ...,
        item_type: typing.Text = ...,
        modules: typing.Optional[typing.Iterable[global___Module]] = ...,
        dyn_id_str: typing.Text = ...,
        orig_dyn_id_str: typing.Text = ...,
        r_type: builtins.int = ...,
        has_fold: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type",b"card_type","dyn_id_str",b"dyn_id_str","has_fold",b"has_fold","item_type",b"item_type","modules",b"modules","orig_dyn_id_str",b"orig_dyn_id_str","r_type",b"r_type"]) -> None: ...
global___DynamicItem = DynamicItem

class Module(google.protobuf.message.Message):
    """模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_TYPE_FIELD_NUMBER: builtins.int
    MODULE_FOLD_FIELD_NUMBER: builtins.int
    MODULE_AUTHOR_FIELD_NUMBER: builtins.int
    MODULE_DYNAMIC_FIELD_NUMBER: builtins.int
    MODULE_STATE_FIELD_NUMBER: builtins.int
    MODULE_FORWARD_FIELD_NUMBER: builtins.int
    MODULE_EXTEND_FIELD_NUMBER: builtins.int
    MODULE_DISPUTE_FIELD_NUMBER: builtins.int
    MODULE_DESC_FIELD_NUMBER: builtins.int
    MODULE_LIKEUSER_FIELD_NUMBER: builtins.int
    MODULE_UPLIST_FIELD_NUMBER: builtins.int
    MODULE_FOLLOWLIST_FIELD_NUMBER: builtins.int
    module_type: typing.Text
    """类型
    fold:折叠 author:发布人 dynamic:动态卡片内容 state:计数信息 forward:转发 extend:小卡信息 dispute:争议小黄条 desc:描述信息
    likeUser:点赞用户 upList:最近访问列表 followList:我的追番
    """

    @property
    def module_fold(self) -> global___ModuleFold:
        """折叠"""
        pass
    @property
    def module_author(self) -> global___ModuleAuthor:
        """发布人"""
        pass
    @property
    def module_dynamic(self) -> global___ModuleDynamic:
        """动态卡片内容"""
        pass
    @property
    def module_state(self) -> global___ModuleState:
        """计数信息"""
        pass
    @property
    def module_forward(self) -> global___ModuleForward:
        """转发"""
        pass
    @property
    def module_extend(self) -> global___ModuleExtend:
        """小卡信息"""
        pass
    @property
    def module_dispute(self) -> global___ModuleDispute:
        """争议小黄条"""
        pass
    @property
    def module_desc(self) -> global___ModuleDesc:
        """描述信息"""
        pass
    @property
    def module_likeUser(self) -> global___ModuleLikeUser:
        """点赞用户"""
        pass
    @property
    def module_upList(self) -> global___ModuleDynUpList:
        """最近访问列表"""
        pass
    @property
    def module_followList(self) -> global___ModuleFollowList:
        """我的追番"""
        pass
    def __init__(self,
        *,
        module_type: typing.Text = ...,
        module_fold: typing.Optional[global___ModuleFold] = ...,
        module_author: typing.Optional[global___ModuleAuthor] = ...,
        module_dynamic: typing.Optional[global___ModuleDynamic] = ...,
        module_state: typing.Optional[global___ModuleState] = ...,
        module_forward: typing.Optional[global___ModuleForward] = ...,
        module_extend: typing.Optional[global___ModuleExtend] = ...,
        module_dispute: typing.Optional[global___ModuleDispute] = ...,
        module_desc: typing.Optional[global___ModuleDesc] = ...,
        module_likeUser: typing.Optional[global___ModuleLikeUser] = ...,
        module_upList: typing.Optional[global___ModuleDynUpList] = ...,
        module_followList: typing.Optional[global___ModuleFollowList] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_author",b"module_author","module_desc",b"module_desc","module_dispute",b"module_dispute","module_dynamic",b"module_dynamic","module_extend",b"module_extend","module_fold",b"module_fold","module_followList",b"module_followList","module_forward",b"module_forward","module_item",b"module_item","module_likeUser",b"module_likeUser","module_state",b"module_state","module_upList",b"module_upList"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_author",b"module_author","module_desc",b"module_desc","module_dispute",b"module_dispute","module_dynamic",b"module_dynamic","module_extend",b"module_extend","module_fold",b"module_fold","module_followList",b"module_followList","module_forward",b"module_forward","module_item",b"module_item","module_likeUser",b"module_likeUser","module_state",b"module_state","module_type",b"module_type","module_upList",b"module_upList"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["module_item",b"module_item"]) -> typing.Optional[typing_extensions.Literal["module_fold","module_author","module_dynamic","module_state","module_forward","module_extend","module_dispute","module_desc","module_likeUser","module_upList","module_followList"]]: ...
global___Module = Module

class ModuleFold(google.protobuf.message.Message):
    """折叠模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FOLD_TYPE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    FOLD_IDS_FIELD_NUMBER: builtins.int
    FOLD_USERS_FIELD_NUMBER: builtins.int
    FOLD_TYPE_V2_FIELD_NUMBER: builtins.int
    fold_type: builtins.int
    """折叠分类(该字段废弃)"""

    text: typing.Text
    """折叠文案"""

    fold_ids: typing.Text
    """被折叠的动态"""

    @property
    def fold_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserInfo]:
        """被折叠的用户信息"""
        pass
    fold_type_v2: global___FoldType.ValueType
    """折叠分类"""

    def __init__(self,
        *,
        fold_type: builtins.int = ...,
        text: typing.Text = ...,
        fold_ids: typing.Text = ...,
        fold_users: typing.Optional[typing.Iterable[global___UserInfo]] = ...,
        fold_type_v2: global___FoldType.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fold_ids",b"fold_ids","fold_type",b"fold_type","fold_type_v2",b"fold_type_v2","fold_users",b"fold_users","text",b"text"]) -> None: ...
global___ModuleFold = ModuleFold

class ModuleAuthor(google.protobuf.message.Message):
    """作者信息模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    PTIME_LABEL_TEXT_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    DECORATE_CARD_FIELD_NUMBER: builtins.int
    id: builtins.int
    """用户mid"""

    ptime_label_text: typing.Text
    """时间标签"""

    @property
    def author(self) -> global___UserInfo:
        """用户详情"""
        pass
    @property
    def decorate_card(self) -> global___DecorateCard:
        """装扮卡片"""
        pass
    def __init__(self,
        *,
        id: builtins.int = ...,
        ptime_label_text: typing.Text = ...,
        author: typing.Optional[global___UserInfo] = ...,
        decorate_card: typing.Optional[global___DecorateCard] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author",b"author","decorate_card",b"decorate_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author",b"author","decorate_card",b"decorate_card","id",b"id","ptime_label_text",b"ptime_label_text"]) -> None: ...
global___ModuleAuthor = ModuleAuthor

class ModuleDispute(google.protobuf.message.Message):
    """争议小黄条模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    desc: typing.Text
    """描述内容"""

    uri: typing.Text
    """跳转链接"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        desc: typing.Text = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","title",b"title","uri",b"uri"]) -> None: ...
global___ModuleDispute = ModuleDispute

class ModuleDesc(google.protobuf.message.Message):
    """文本内容模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DESC_FIELD_NUMBER: builtins.int
    @property
    def desc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Description]:
        """文本描述"""
        pass
    def __init__(self,
        *,
        desc: typing.Optional[typing.Iterable[global___Description]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc"]) -> None: ...
global___ModuleDesc = ModuleDesc

class ModuleDynamic(google.protobuf.message.Message):
    """动态详情模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CARD_TYPE_FIELD_NUMBER: builtins.int
    CARD_UGC_FIELD_NUMBER: builtins.int
    CARD_PGC_FIELD_NUMBER: builtins.int
    CARD_CURR_SEASON_FIELD_NUMBER: builtins.int
    CARD_CURR_BATCH_FIELD_NUMBER: builtins.int
    card_type: typing.Text
    """卡片类型 
    ugc:ugc卡 pgc:pgc卡 currSeason:付费课程系列 currBatch:付费课程批次
    """

    @property
    def card_ugc(self) -> global___CardUGC:
        """ugc卡"""
        pass
    @property
    def card_pgc(self) -> global___CardPGC:
        """pgc卡"""
        pass
    @property
    def card_curr_season(self) -> global___CardCurrSeason:
        """付费课程系列"""
        pass
    @property
    def card_curr_batch(self) -> global___CardCurrBatch:
        """付费课程批次"""
        pass
    def __init__(self,
        *,
        card_type: typing.Text = ...,
        card_ugc: typing.Optional[global___CardUGC] = ...,
        card_pgc: typing.Optional[global___CardPGC] = ...,
        card_curr_season: typing.Optional[global___CardCurrSeason] = ...,
        card_curr_batch: typing.Optional[global___CardCurrBatch] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card",b"card","card_curr_batch",b"card_curr_batch","card_curr_season",b"card_curr_season","card_pgc",b"card_pgc","card_ugc",b"card_ugc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card",b"card","card_curr_batch",b"card_curr_batch","card_curr_season",b"card_curr_season","card_pgc",b"card_pgc","card_type",b"card_type","card_ugc",b"card_ugc"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["card",b"card"]) -> typing.Optional[typing_extensions.Literal["card_ugc","card_pgc","card_curr_season","card_curr_batch"]]: ...
global___ModuleDynamic = ModuleDynamic

class ModuleLikeUser(google.protobuf.message.Message):
    """点赞用户模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIKE_USERS_FIELD_NUMBER: builtins.int
    DISPLAY_TEXT_FIELD_NUMBER: builtins.int
    @property
    def like_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LikeUser]:
        """点赞用户"""
        pass
    display_text: typing.Text
    """文案"""

    def __init__(self,
        *,
        like_users: typing.Optional[typing.Iterable[global___LikeUser]] = ...,
        display_text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_text",b"display_text","like_users",b"like_users"]) -> None: ...
global___ModuleLikeUser = ModuleLikeUser

class ModuleState(google.protobuf.message.Message):
    """计数信息模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REPOST_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    LIKE_INFO_FIELD_NUMBER: builtins.int
    NO_COMMENT_FIELD_NUMBER: builtins.int
    NO_FORWARD_FIELD_NUMBER: builtins.int
    repost: builtins.int
    """转发数"""

    like: builtins.int
    """点赞数"""

    reply: builtins.int
    """评论数"""

    @property
    def like_info(self) -> global___LikeInfo:
        """点赞拓展信息"""
        pass
    no_comment: builtins.bool
    """禁评"""

    no_forward: builtins.bool
    """禁转"""

    def __init__(self,
        *,
        repost: builtins.int = ...,
        like: builtins.int = ...,
        reply: builtins.int = ...,
        like_info: typing.Optional[global___LikeInfo] = ...,
        no_comment: builtins.bool = ...,
        no_forward: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["like_info",b"like_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["like",b"like","like_info",b"like_info","no_comment",b"no_comment","no_forward",b"no_forward","reply",b"reply","repost",b"repost"]) -> None: ...
global___ModuleState = ModuleState

class ModuleForward(google.protobuf.message.Message):
    """转发模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CARD_TYPE_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    card_type: typing.Text
    """卡片类型"""

    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Module]:
        """嵌套模型"""
        pass
    def __init__(self,
        *,
        card_type: typing.Text = ...,
        modules: typing.Optional[typing.Iterable[global___Module]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type",b"card_type","modules",b"modules"]) -> None: ...
global___ModuleForward = ModuleForward

class CardUGC(google.protobuf.message.Message):
    """UGC视频卡片数据"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    MEDIA_TYPE_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    cover: typing.Text
    """封面图"""

    uri: typing.Text
    """秒开地址"""

    cover_left_text_1: typing.Text
    """视频封面展示项 1"""

    cover_left_text_2: typing.Text
    """视频封面展示项 2"""

    cover_left_text_3: typing.Text
    """封面视频展示项 3"""

    avid: builtins.int
    """avid"""

    cid: builtins.int
    """cid"""

    media_type: global___MediaType.ValueType
    """视频源类型"""

    @property
    def dimension(self) -> global___Dimension:
        """尺寸信息"""
        pass
    @property
    def badge(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """角标"""
        pass
    can_play: builtins.int
    """是否能够自动播放"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        uri: typing.Text = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_text_2: typing.Text = ...,
        cover_left_text_3: typing.Text = ...,
        avid: builtins.int = ...,
        cid: builtins.int = ...,
        media_type: global___MediaType.ValueType = ...,
        dimension: typing.Optional[global___Dimension] = ...,
        badge: typing.Optional[typing.Iterable[global___VideoBadge]] = ...,
        can_play: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension",b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avid",b"avid","badge",b"badge","can_play",b"can_play","cid",b"cid","cover",b"cover","cover_left_text_1",b"cover_left_text_1","cover_left_text_2",b"cover_left_text_2","cover_left_text_3",b"cover_left_text_3","dimension",b"dimension","media_type",b"media_type","title",b"title","uri",b"uri"]) -> None: ...
global___CardUGC = CardUGC

class CardPGC(google.protobuf.message.Message):
    """PGC视频卡片数据"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    EPID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    MEDIA_TYPE_FIELD_NUMBER: builtins.int
    SUB_TYPE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    CAN_PLAY_FIELD_NUMBER: builtins.int
    SEASON_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    cover: typing.Text
    """封面图"""

    uri: typing.Text
    """秒开地址"""

    cover_left_text_1: typing.Text
    """视频封面展示项 1"""

    cover_left_text_2: typing.Text
    """视频封面展示项 2"""

    cover_left_text_3: typing.Text
    """封面视频展示项 3"""

    cid: builtins.int
    """cid"""

    season_id: builtins.int
    """season_id"""

    epid: builtins.int
    """epid"""

    aid: builtins.int
    """aid"""

    media_type: global___MediaType.ValueType
    """视频源类型"""

    sub_type: global___VideoSubType.ValueType
    """番剧类型"""

    is_preview: builtins.int
    """番剧是否为预览视频 0:否，1:是"""

    @property
    def dimension(self) -> global___Dimension:
        """尺寸信息"""
        pass
    @property
    def badge(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """角标"""
        pass
    can_play: builtins.int
    """是否能够自动播放"""

    @property
    def season(self) -> global___PGCSeason:
        """PGC单季信息"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        uri: typing.Text = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_text_2: typing.Text = ...,
        cover_left_text_3: typing.Text = ...,
        cid: builtins.int = ...,
        season_id: builtins.int = ...,
        epid: builtins.int = ...,
        aid: builtins.int = ...,
        media_type: global___MediaType.ValueType = ...,
        sub_type: global___VideoSubType.ValueType = ...,
        is_preview: builtins.int = ...,
        dimension: typing.Optional[global___Dimension] = ...,
        badge: typing.Optional[typing.Iterable[global___VideoBadge]] = ...,
        can_play: builtins.int = ...,
        season: typing.Optional[global___PGCSeason] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension",b"dimension","season",b"season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","badge",b"badge","can_play",b"can_play","cid",b"cid","cover",b"cover","cover_left_text_1",b"cover_left_text_1","cover_left_text_2",b"cover_left_text_2","cover_left_text_3",b"cover_left_text_3","dimension",b"dimension","epid",b"epid","is_preview",b"is_preview","media_type",b"media_type","season",b"season","season_id",b"season_id","sub_type",b"sub_type","title",b"title","uri",b"uri"]) -> None: ...
global___CardPGC = CardPGC

class CardCurrSeason(google.protobuf.message.Message):
    """付费课程系列卡"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TEXT_1_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    cover: typing.Text
    """封面图"""

    uri: typing.Text
    """跳转地址"""

    text_1: typing.Text
    """展示项 1(更新信息)"""

    desc: typing.Text
    """描述信息"""

    @property
    def badge(self) -> global___VideoBadge:
        """角标"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        uri: typing.Text = ...,
        text_1: typing.Text = ...,
        desc: typing.Text = ...,
        badge: typing.Optional[global___VideoBadge] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge",b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","cover",b"cover","desc",b"desc","text_1",b"text_1","title",b"title","uri",b"uri"]) -> None: ...
global___CardCurrSeason = CardCurrSeason

class CardCurrBatch(google.protobuf.message.Message):
    """付费课程批次卡"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TEXT_1_FIELD_NUMBER: builtins.int
    TEXT_2_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    cover: typing.Text
    """封面图"""

    uri: typing.Text
    """跳转地址"""

    text_1: typing.Text
    """展示项 1(本集标题)"""

    text_2: typing.Text
    """展示项 2(更新了多少个视频)"""

    @property
    def badge(self) -> global___VideoBadge:
        """角标"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        uri: typing.Text = ...,
        text_1: typing.Text = ...,
        text_2: typing.Text = ...,
        badge: typing.Optional[global___VideoBadge] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge",b"badge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","cover",b"cover","text_1",b"text_1","text_2",b"text_2","title",b"title","uri",b"uri"]) -> None: ...
global___CardCurrBatch = CardCurrBatch

class VideoBadge(google.protobuf.message.Message):
    """角标信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    text: typing.Text
    """文案"""

    text_color: typing.Text
    """文案颜色-日间"""

    text_color_night: typing.Text
    """文案颜色-夜间"""

    bg_color: typing.Text
    """背景颜色-日间"""

    bg_color_night: typing.Text
    """背景颜色-夜间"""

    border_color: typing.Text
    """边框颜色-日间"""

    border_color_night: typing.Text
    """边框颜色-夜间"""

    bg_style: builtins.int
    """样式"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        text_color: typing.Text = ...,
        text_color_night: typing.Text = ...,
        bg_color: typing.Text = ...,
        bg_color_night: typing.Text = ...,
        border_color: typing.Text = ...,
        border_color_night: typing.Text = ...,
        bg_style: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","bg_color_night",b"bg_color_night","bg_style",b"bg_style","border_color",b"border_color","border_color_night",b"border_color_night","text",b"text","text_color",b"text_color","text_color_night",b"text_color_night"]) -> None: ...
global___VideoBadge = VideoBadge

class Dimension(google.protobuf.message.Message):
    """尺寸信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HEIGHT_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    height: builtins.int
    width: builtins.int
    rotate: builtins.int
    def __init__(self,
        *,
        height: builtins.int = ...,
        width: builtins.int = ...,
        rotate: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height","rotate",b"rotate","width",b"width"]) -> None: ...
global___Dimension = Dimension

class ModuleExtend(google.protobuf.message.Message):
    """拓展信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXTEND_FIELD_NUMBER: builtins.int
    @property
    def extend(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Extend]:
        """拓展"""
        pass
    def __init__(self,
        *,
        extend: typing.Optional[typing.Iterable[global___Extend]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extend",b"extend"]) -> None: ...
global___ModuleExtend = ModuleExtend

class Extend(google.protobuf.message.Message):
    """拓展"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    EXT_INFO_TOPIC_FIELD_NUMBER: builtins.int
    EXT_INFO_LBS_FIELD_NUMBER: builtins.int
    EXT_INFO_HOT_FIELD_NUMBER: builtins.int
    EXT_INFO_GAME_FIELD_NUMBER: builtins.int
    type: typing.Text
    """类型
    topic:话题小卡 lbs:lbs hot:热门视频 game:游戏
    """

    @property
    def ext_info_topic(self) -> global___ExtInfoTopic:
        """话题小卡"""
        pass
    @property
    def ext_info_lbs(self) -> global___ExtInfoLBS:
        """lbs"""
        pass
    @property
    def ext_info_hot(self) -> global___ExtInfoHot:
        """热门视频"""
        pass
    @property
    def ext_info_game(self) -> global___ExtInfoGame:
        """游戏"""
        pass
    def __init__(self,
        *,
        type: typing.Text = ...,
        ext_info_topic: typing.Optional[global___ExtInfoTopic] = ...,
        ext_info_lbs: typing.Optional[global___ExtInfoLBS] = ...,
        ext_info_hot: typing.Optional[global___ExtInfoHot] = ...,
        ext_info_game: typing.Optional[global___ExtInfoGame] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ext_info_game",b"ext_info_game","ext_info_hot",b"ext_info_hot","ext_info_lbs",b"ext_info_lbs","ext_info_topic",b"ext_info_topic","extend",b"extend"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ext_info_game",b"ext_info_game","ext_info_hot",b"ext_info_hot","ext_info_lbs",b"ext_info_lbs","ext_info_topic",b"ext_info_topic","extend",b"extend","type",b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["extend",b"extend"]) -> typing.Optional[typing_extensions.Literal["ext_info_topic","ext_info_lbs","ext_info_hot","ext_info_game"]]: ...
global___Extend = Extend

class ExtInfoGame(google.protobuf.message.Message):
    """拓展信息-游戏小卡"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    uri: typing.Text
    """跳转地址"""

    icon: typing.Text
    """小图标"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        icon: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","title",b"title","uri",b"uri"]) -> None: ...
global___ExtInfoGame = ExtInfoGame

class ExtInfoTopic(google.protobuf.message.Message):
    """拓展信息-话题小卡"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题-话题名"""

    uri: typing.Text
    """跳转地址"""

    icon: typing.Text
    """小图标"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        icon: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","title",b"title","uri",b"uri"]) -> None: ...
global___ExtInfoTopic = ExtInfoTopic

class ExtInfoLBS(google.protobuf.message.Message):
    """拓展信息-lbs"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    POI_TYPE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    uri: typing.Text
    """跳转地址"""

    icon: typing.Text
    """小图标"""

    poi_type: builtins.int
    """poiType"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        icon: typing.Text = ...,
        poi_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","poi_type",b"poi_type","title",b"title","uri",b"uri"]) -> None: ...
global___ExtInfoLBS = ExtInfoLBS

class ExtInfoHot(google.protobuf.message.Message):
    """拓展信息-热门视频"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    uri: typing.Text
    """跳转地址"""

    icon: typing.Text
    """小图标"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        icon: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","title",b"title","uri",b"uri"]) -> None: ...
global___ExtInfoHot = ExtInfoHot

class LikeInfo(google.protobuf.message.Message):
    """点赞拓展信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ANIMATION_FIELD_NUMBER: builtins.int
    IS_LIKE_FIELD_NUMBER: builtins.int
    @property
    def animation(self) -> global___LikeAnimation:
        """点赞动画"""
        pass
    is_like: builtins.int
    """是否点赞"""

    def __init__(self,
        *,
        animation: typing.Optional[global___LikeAnimation] = ...,
        is_like: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["animation",b"animation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["animation",b"animation","is_like",b"is_like"]) -> None: ...
global___LikeInfo = LikeInfo

class LikeUser(google.protobuf.message.Message):
    """点赞用户"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    UNAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户mid"""

    uname: typing.Text
    """用户昵称"""

    uri: typing.Text
    """点击跳转链接"""

    def __init__(self,
        *,
        uid: builtins.int = ...,
        uname: typing.Text = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["uid",b"uid","uname",b"uname","uri",b"uri"]) -> None: ...
global___LikeUser = LikeUser

class LikeAnimation(google.protobuf.message.Message):
    """点赞动画"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BEGIN_FIELD_NUMBER: builtins.int
    PROC_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    LIKE_ICON_ID_FIELD_NUMBER: builtins.int
    begin: typing.Text
    """开始动画"""

    proc: typing.Text
    """过程动画"""

    end: typing.Text
    """结束动画"""

    like_icon_id: builtins.int
    """id"""

    def __init__(self,
        *,
        begin: typing.Text = ...,
        proc: typing.Text = ...,
        end: typing.Text = ...,
        like_icon_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["begin",b"begin","end",b"end","like_icon_id",b"like_icon_id","proc",b"proc"]) -> None: ...
global___LikeAnimation = LikeAnimation

class Description(google.protobuf.message.Message):
    """文本描述"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    EMOJI_TYPE_FIELD_NUMBER: builtins.int
    GOODS_TYPE_FIELD_NUMBER: builtins.int
    text: typing.Text
    """文本内容"""

    type: typing.Text
    """文本类型"""

    uri: typing.Text
    """点击跳转链接"""

    emoji_type: typing.Text
    """emoji类型"""

    goods_type: typing.Text
    """商品类型"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        type: typing.Text = ...,
        uri: typing.Text = ...,
        emoji_type: typing.Text = ...,
        goods_type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["emoji_type",b"emoji_type","goods_type",b"goods_type","text",b"text","type",b"type","uri",b"uri"]) -> None: ...
global___Description = Description

class DecorateCard(google.protobuf.message.Message):
    """装扮卡片"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    CARD_URL_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    FAN_FIELD_NUMBER: builtins.int
    id: builtins.int
    """装扮卡片id"""

    card_url: typing.Text
    """装扮卡片链接"""

    jump_url: typing.Text
    """装扮卡片点击跳转链接"""

    @property
    def fan(self) -> global___DecoCardFan:
        """粉丝样式"""
        pass
    def __init__(self,
        *,
        id: builtins.int = ...,
        card_url: typing.Text = ...,
        jump_url: typing.Text = ...,
        fan: typing.Optional[global___DecoCardFan] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fan",b"fan"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_url",b"card_url","fan",b"fan","id",b"id","jump_url",b"jump_url"]) -> None: ...
global___DecorateCard = DecorateCard

class DecoCardFan(google.protobuf.message.Message):
    """粉丝样式"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_FAN_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    is_fan: builtins.int
    """是否是粉丝"""

    number: builtins.int
    """数量"""

    color: typing.Text
    """颜色"""

    def __init__(self,
        *,
        is_fan: builtins.int = ...,
        number: builtins.int = ...,
        color: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["color",b"color","is_fan",b"is_fan","number",b"number"]) -> None: ...
global___DecoCardFan = DecoCardFan

class UserInfo(google.protobuf.message.Message):
    """用户信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    LIVE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    PENDANT_FIELD_NUMBER: builtins.int
    NAMEPLATE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""

    name: typing.Text
    """用户昵称"""

    face: typing.Text
    """用户头像"""

    @property
    def official(self) -> global___OfficialVerify:
        """认证信息"""
        pass
    @property
    def vip(self) -> global___VipInfo:
        """大会员信息"""
        pass
    @property
    def live(self) -> global___LiveInfo:
        """直播信息"""
        pass
    uri: typing.Text
    """空间页跳转链接"""

    @property
    def pendant(self) -> global___UserPendant:
        """挂件信息"""
        pass
    @property
    def nameplate(self) -> global___Nameplate:
        """认证名牌"""
        pass
    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        official: typing.Optional[global___OfficialVerify] = ...,
        vip: typing.Optional[global___VipInfo] = ...,
        live: typing.Optional[global___LiveInfo] = ...,
        uri: typing.Text = ...,
        pendant: typing.Optional[global___UserPendant] = ...,
        nameplate: typing.Optional[global___Nameplate] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["live",b"live","nameplate",b"nameplate","official",b"official","pendant",b"pendant","vip",b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","live",b"live","mid",b"mid","name",b"name","nameplate",b"nameplate","official",b"official","pendant",b"pendant","uri",b"uri","vip",b"vip"]) -> None: ...
global___UserInfo = UserInfo

class Nameplate(google.protobuf.message.Message):
    """认证名牌"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    IMAGE_SMALL_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    nid: builtins.int
    """nid"""

    name: typing.Text
    """名称"""

    image: typing.Text
    """图片地址"""

    image_small: typing.Text
    """小图地址"""

    level: typing.Text
    """等级"""

    condition: typing.Text
    """获取条件"""

    def __init__(self,
        *,
        nid: builtins.int = ...,
        name: typing.Text = ...,
        image: typing.Text = ...,
        image_small: typing.Text = ...,
        level: typing.Text = ...,
        condition: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition",b"condition","image",b"image","image_small",b"image_small","level",b"level","name",b"name","nid",b"nid"]) -> None: ...
global___Nameplate = Nameplate

class UserPendant(google.protobuf.message.Message):
    """头像挂件信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    EXPIRE_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """pid"""

    name: typing.Text
    """名称"""

    image: typing.Text
    """图片链接"""

    expire: builtins.int
    """有效期"""

    def __init__(self,
        *,
        pid: builtins.int = ...,
        name: typing.Text = ...,
        image: typing.Text = ...,
        expire: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expire",b"expire","image",b"image","name",b"name","pid",b"pid"]) -> None: ...
global___UserPendant = UserPendant

class OfficialVerify(google.protobuf.message.Message):
    """认证信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    IS_ATTEN_FIELD_NUMBER: builtins.int
    type: builtins.int
    """认证类型
    127:未认证 0:个人 1:机构
    """

    desc: typing.Text
    """认证描述"""

    is_atten: builtins.int
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        desc: typing.Text = ...,
        is_atten: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","is_atten",b"is_atten","type",b"type"]) -> None: ...
global___OfficialVerify = OfficialVerify

class VipInfo(google.protobuf.message.Message):
    """大会员信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    Type: builtins.int
    """大会员类型"""

    status: builtins.int
    """大会员状态"""

    due_date: builtins.int
    """到期时间"""

    @property
    def label(self) -> global___VipLabel:
        """标签"""
        pass
    theme_type: builtins.int
    """主题"""

    def __init__(self,
        *,
        Type: builtins.int = ...,
        status: builtins.int = ...,
        due_date: builtins.int = ...,
        label: typing.Optional[global___VipLabel] = ...,
        theme_type: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label",b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["Type",b"Type","due_date",b"due_date","label",b"label","status",b"status","theme_type",b"theme_type"]) -> None: ...
global___VipInfo = VipInfo

class VipLabel(google.protobuf.message.Message):
    """大会员标签"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PATH_FIELD_NUMBER: builtins.int
    path: typing.Text
    """图片地址"""

    def __init__(self,
        *,
        path: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path",b"path"]) -> None: ...
global___VipLabel = VipLabel

class LiveInfo(google.protobuf.message.Message):
    """直播信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_LIVING_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    is_living: builtins.int
    """是否在直播
    0:未直播 1:正在直播
    """

    uri: typing.Text
    """跳转链接"""

    def __init__(self,
        *,
        is_living: builtins.int = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_living",b"is_living","uri",b"uri"]) -> None: ...
global___LiveInfo = LiveInfo

class DynDetailsReq(google.protobuf.message.Message):
    """批量动态id获取动态详情请求参数"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    DYNAMIC_IDS_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    teenagers_mode: builtins.int
    """青少年模式"""

    dynamic_ids: typing.Text
    """动态id"""

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """流版本"""

    fnval: builtins.int
    """流功能"""

    force_host: builtins.int
    """是否强制使用域名"""

    fourk: builtins.int
    """是否4k"""

    def __init__(self,
        *,
        teenagers_mode: builtins.int = ...,
        dynamic_ids: typing.Text = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dynamic_ids",b"dynamic_ids","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","qn",b"qn","teenagers_mode",b"teenagers_mode"]) -> None: ...
global___DynDetailsReq = DynDetailsReq

class DynDetailsReply(google.protobuf.message.Message):
    """批量动态id获取动态详情返回值"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
        pass
    def __init__(self,
        *,
        list: typing.Optional[typing.Iterable[global___DynamicItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list",b"list"]) -> None: ...
global___DynDetailsReply = DynDetailsReply

class SVideoReq(google.protobuf.message.Message):
    """小视频连播页-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PLAYER_PRELOAD_FIELD_NUMBER: builtins.int
    FOCUS_AID_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """当前素材的id"""

    type: global___SVideoType.ValueType
    """当前素材类型
    1:动态(如果有oid则必传) 2:热门分类 3:热点聚合
    """

    offset: typing.Text
    """翻页offset"""

    qn: builtins.int
    """清晰度(旧版)"""

    fnver: builtins.int
    """流版本(旧版)"""

    fnval: builtins.int
    """流类型(旧版)"""

    force_host: builtins.int
    """是否强制使用域名(旧版)"""

    fourk: builtins.int
    """是否4k(旧版)"""

    spmid: typing.Text
    """当前页面spm"""

    from_spmid: typing.Text
    """上级页面spm"""

    @property
    def player_preload(self) -> global___PlayerPreloadParams:
        """秒开参数"""
        pass
    focus_aid: builtins.int
    """热门进入联播页的锚点aid"""

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
        pass
    def __init__(self,
        *,
        oid: builtins.int = ...,
        type: global___SVideoType.ValueType = ...,
        offset: typing.Text = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        player_preload: typing.Optional[global___PlayerPreloadParams] = ...,
        focus_aid: builtins.int = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args",b"player_args","player_preload",b"player_preload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval",b"fnval","fnver",b"fnver","focus_aid",b"focus_aid","force_host",b"force_host","fourk",b"fourk","from_spmid",b"from_spmid","offset",b"offset","oid",b"oid","player_args",b"player_args","player_preload",b"player_preload","qn",b"qn","spmid",b"spmid","type",b"type"]) -> None: ...
global___SVideoReq = SVideoReq

class SVideoReply(google.protobuf.message.Message):
    """小视频连播页-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIST_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    TOP_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SVideoItem]:
        """列表"""
        pass
    offset: typing.Text
    """翻页游标"""

    has_more: builtins.int
    """是否还有更多数据
    1:有
    """

    @property
    def top(self) -> global___SVideoTop:
        """顶部"""
        pass
    def __init__(self,
        *,
        list: typing.Optional[typing.Iterable[global___SVideoItem]] = ...,
        offset: typing.Text = ...,
        has_more: builtins.int = ...,
        top: typing.Optional[global___SVideoTop] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["top",b"top"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more",b"has_more","list",b"list","offset",b"offset","top",b"top"]) -> None: ...
global___SVideoReply = SVideoReply

class SVideoTop(google.protobuf.message.Message):
    """顶部"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    Title: typing.Text
    """联播页标题"""

    Desc: typing.Text
    """联播页导语"""

    def __init__(self,
        *,
        Title: typing.Text = ...,
        Desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["Desc",b"Desc","Title",b"Title"]) -> None: ...
global___SVideoTop = SVideoTop

class PlayerPreloadParams(google.protobuf.message.Message):
    """秒开参数"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """流版本"""

    fnval: builtins.int
    """流类型"""

    force_host: builtins.int
    """是否强制使用域名"""

    fourk: builtins.int
    """是否4k"""

    def __init__(self,
        *,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","qn",b"qn"]) -> None: ...
global___PlayerPreloadParams = PlayerPreloadParams

class SVideoItem(google.protobuf.message.Message):
    """小视频卡片项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CARD_TYPE_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    DYN_ID_STR_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    card_type: typing.Text
    """卡片类型
    av:稿件视频
    """

    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SVideoModule]:
        """模块内容"""
        pass
    dyn_id_str: typing.Text
    """动态ID str"""

    index: builtins.int
    """卡片游标"""

    def __init__(self,
        *,
        card_type: typing.Text = ...,
        modules: typing.Optional[typing.Iterable[global___SVideoModule]] = ...,
        dyn_id_str: typing.Text = ...,
        index: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type",b"card_type","dyn_id_str",b"dyn_id_str","index",b"index","modules",b"modules"]) -> None: ...
global___SVideoItem = SVideoItem

class SVideoModule(google.protobuf.message.Message):
    """小视频模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_TYPE_FIELD_NUMBER: builtins.int
    MODULE_AUTHOR_FIELD_NUMBER: builtins.int
    MODULE_PLAYER_FIELD_NUMBER: builtins.int
    MODULE_DESC_FIELD_NUMBER: builtins.int
    MODULE_STAT_FIELD_NUMBER: builtins.int
    module_type: typing.Text
    """类型
    author:发布人 player:播放器内容 desc:描述信息 stat:计数信息
    """

    @property
    def module_author(self) -> global___SVideoModuleAuthor:
        """发布人"""
        pass
    @property
    def module_player(self) -> global___SVideoModulePlayer:
        """播放器内容"""
        pass
    @property
    def module_desc(self) -> global___SVideoModuleDesc:
        """描述信息"""
        pass
    @property
    def module_stat(self) -> global___SVideoModuleStat:
        """计数信息"""
        pass
    def __init__(self,
        *,
        module_type: typing.Text = ...,
        module_author: typing.Optional[global___SVideoModuleAuthor] = ...,
        module_player: typing.Optional[global___SVideoModulePlayer] = ...,
        module_desc: typing.Optional[global___SVideoModuleDesc] = ...,
        module_stat: typing.Optional[global___SVideoModuleStat] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_author",b"module_author","module_desc",b"module_desc","module_item",b"module_item","module_player",b"module_player","module_stat",b"module_stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_author",b"module_author","module_desc",b"module_desc","module_item",b"module_item","module_player",b"module_player","module_stat",b"module_stat","module_type",b"module_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["module_item",b"module_item"]) -> typing.Optional[typing_extensions.Literal["module_author","module_player","module_desc","module_stat"]]: ...
global___SVideoModule = SVideoModule

class SVideoModuleAuthor(google.protobuf.message.Message):
    """作者信息模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    PUB_DESC_FIELD_NUMBER: builtins.int
    IS_ATTENTION_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""

    name: typing.Text
    """用户昵称"""

    face: typing.Text
    """用户头像"""

    pub_desc: typing.Text
    """发布描述"""

    is_attention: builtins.int
    """是否关注up
    1:已关注
    """

    uri: typing.Text
    """跳转地址"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        pub_desc: typing.Text = ...,
        is_attention: builtins.int = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","is_attention",b"is_attention","mid",b"mid","name",b"name","pub_desc",b"pub_desc","uri",b"uri"]) -> None: ...
global___SVideoModuleAuthor = SVideoModuleAuthor

class SVideoModulePlayer(google.protobuf.message.Message):
    """播放器模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    cover: typing.Text
    """封面图"""

    uri: typing.Text
    """跳转地址，秒开地址如果有会拼接player_preload可参考天马"""

    aid: builtins.int
    """aid"""

    cid: builtins.int
    """cid"""

    duration: builtins.int
    """视频时长"""

    @property
    def dimension(self) -> global___Dimension:
        """尺寸信息"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        uri: typing.Text = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        duration: builtins.int = ...,
        dimension: typing.Optional[global___Dimension] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dimension",b"dimension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","cid",b"cid","cover",b"cover","dimension",b"dimension","duration",b"duration","title",b"title","uri",b"uri"]) -> None: ...
global___SVideoModulePlayer = SVideoModulePlayer

class SVideoModuleDesc(google.protobuf.message.Message):
    """文本内容模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    text: typing.Text
    """文本内容"""

    uri: typing.Text
    """跳转地址"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text",b"text","uri",b"uri"]) -> None: ...
global___SVideoModuleDesc = SVideoModuleDesc

class SVideoModuleStat(google.protobuf.message.Message):
    """计数信息模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STAT_INFO_FIELD_NUMBER: builtins.int
    SHARE_INFO_FIELD_NUMBER: builtins.int
    @property
    def stat_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SVideoStatInfo]:
        """计数内容"""
        pass
    @property
    def share_info(self) -> global___ShareInfo:
        """分享需要"""
        pass
    def __init__(self,
        *,
        stat_info: typing.Optional[typing.Iterable[global___SVideoStatInfo]] = ...,
        share_info: typing.Optional[global___ShareInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["share_info",b"share_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_info",b"share_info","stat_info",b"stat_info"]) -> None: ...
global___SVideoModuleStat = SVideoModuleStat

class SVideoStatInfo(google.protobuf.message.Message):
    """计数内容"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ICON_FIELD_NUMBER: builtins.int
    NUM_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    icon: builtins.int
    """计数icon
    1:分享符号 2:评论符号 3:点赞符号
    """

    num: builtins.int
    """计数值"""

    selected: builtins.int
    """选中状态
    1:选中
    """

    uri: typing.Text
    """跳转链接(如评论)"""

    def __init__(self,
        *,
        icon: builtins.int = ...,
        num: builtins.int = ...,
        selected: builtins.int = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","num",b"num","selected",b"selected","uri",b"uri"]) -> None: ...
global___SVideoStatInfo = SVideoStatInfo

class ShareInfo(google.protobuf.message.Message):
    """分享需要"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""

    bvid: typing.Text
    """稿件bvid"""

    title: typing.Text
    """标题"""

    subtitle: typing.Text
    """副标题"""

    cover: typing.Text
    """稿件封面"""

    mid: builtins.int
    """up mid"""

    name: typing.Text
    """up昵称"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        bvid: typing.Text = ...,
        title: typing.Text = ...,
        subtitle: typing.Text = ...,
        cover: typing.Text = ...,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","bvid",b"bvid","cover",b"cover","mid",b"mid","name",b"name","subtitle",b"subtitle","title",b"title"]) -> None: ...
global___ShareInfo = ShareInfo

class DynTabReq(google.protobuf.message.Message):
    """动态tab页-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    teenagers_mode: builtins.int
    """青少年模式
    1:开启青少年模式
    """

    def __init__(self,
        *,
        teenagers_mode: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["teenagers_mode",b"teenagers_mode"]) -> None: ...
global___DynTabReq = DynTabReq

class DynTabReply(google.protobuf.message.Message):
    """动态tab页-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DYN_TAB_FIELD_NUMBER: builtins.int
    @property
    def dyn_tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynTab]:
        """动态tab详情列表"""
        pass
    def __init__(self,
        *,
        dyn_tab: typing.Optional[typing.Iterable[global___DynTab]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_tab",b"dyn_tab"]) -> None: ...
global___DynTabReply = DynTabReply

class DynTab(google.protobuf.message.Message):
    """动态tab详情"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    BUBBLE_FIELD_NUMBER: builtins.int
    RED_POINT_FIELD_NUMBER: builtins.int
    CITY_ID_FIELD_NUMBER: builtins.int
    IS_POPUP_FIELD_NUMBER: builtins.int
    POPUP_FIELD_NUMBER: builtins.int
    DEFAULTTAB_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    ANCHOR_FIELD_NUMBER: builtins.int
    INTERNAL_TEST_FIELD_NUMBER: builtins.int
    title: typing.Text
    """tab标题 优先展示用,未开启状态第一次请求返回同城,后续请求返回对应城市名"""

    uri: typing.Text
    """跳转链接"""

    bubble: typing.Text
    """气泡内容"""

    red_point: builtins.int
    """是否推红点"""

    city_id: builtins.int
    """城市ID"""

    is_popup: builtins.int
    """是否弹窗"""

    @property
    def popup(self) -> global___Popup:
        """弹窗内容"""
        pass
    defaultTab: builtins.bool
    """是否默认tab"""

    sub_title: typing.Text
    """副标题 对应城市名"""

    anchor: typing.Text
    """锚点字段"""

    internal_test: typing.Text
    """内测文案"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        bubble: typing.Text = ...,
        red_point: builtins.int = ...,
        city_id: builtins.int = ...,
        is_popup: builtins.int = ...,
        popup: typing.Optional[global___Popup] = ...,
        defaultTab: builtins.bool = ...,
        sub_title: typing.Text = ...,
        anchor: typing.Text = ...,
        internal_test: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["popup",b"popup"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor",b"anchor","bubble",b"bubble","city_id",b"city_id","defaultTab",b"defaultTab","internal_test",b"internal_test","is_popup",b"is_popup","popup",b"popup","red_point",b"red_point","sub_title",b"sub_title","title",b"title","uri",b"uri"]) -> None: ...
global___DynTab = DynTab

class Popup(google.protobuf.message.Message):
    """动态tab弹窗详情"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    desc: typing.Text
    """文案"""

    uri: typing.Text
    """文案附加跳转地址"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        desc: typing.Text = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","title",b"title","uri",b"uri"]) -> None: ...
global___Popup = Popup

class DynOurCitySwitchReq(google.protobuf.message.Message):
    """动态同城开关-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SWITCH_FIELD_NUMBER: builtins.int
    switch: builtins.int
    """开关参数
    0:关闭 1:开启
    """

    def __init__(self,
        *,
        switch: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["switch",b"switch"]) -> None: ...
global___DynOurCitySwitchReq = DynOurCitySwitchReq

class DynOurCityReq(google.protobuf.message.Message):
    """动态同城页-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CITY_ID_FIELD_NUMBER: builtins.int
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    LBS_STATE_FIELD_NUMBER: builtins.int
    REFRESH_CITY_FIELD_NUMBER: builtins.int
    EXP_CONF_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    CITY_CODE_FIELD_NUMBER: builtins.int
    BUILD_TIME_FIELD_NUMBER: builtins.int
    city_id: builtins.int
    """城市ID"""

    lat: builtins.float
    """纬度"""

    lng: builtins.float
    """经度"""

    offset: typing.Text
    """透传上一次接口请求返回的offset"""

    page_size: builtins.int
    """每页元素个数"""

    teenagers_mode: builtins.int
    """青少年模式
    1:开启青少年模式
    """

    qn: builtins.int
    """清晰度(旧版)"""

    fnver: builtins.int
    """流版本(旧版)"""

    fnval: builtins.int
    """流类型(旧版)"""

    force_host: builtins.int
    """是否强制使用域名(旧版)"""

    fourk: builtins.int
    """是否4k(旧版)"""

    lbs_state: builtins.int
    """是否开启lbs
    0:关闭 1:开启
    """

    refresh_city: builtins.int
    """是否刷新城市"""

    @property
    def exp_conf(self) -> global___ExpConf:
        """魔镜设置"""
        pass
    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
        pass
    city_code: builtins.int
    """城市码"""

    build_time: builtins.int
    """构建时间"""

    def __init__(self,
        *,
        city_id: builtins.int = ...,
        lat: builtins.float = ...,
        lng: builtins.float = ...,
        offset: typing.Text = ...,
        page_size: builtins.int = ...,
        teenagers_mode: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
        lbs_state: builtins.int = ...,
        refresh_city: builtins.int = ...,
        exp_conf: typing.Optional[global___ExpConf] = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        city_code: builtins.int = ...,
        build_time: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exp_conf",b"exp_conf","player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_time",b"build_time","city_code",b"city_code","city_id",b"city_id","exp_conf",b"exp_conf","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","lat",b"lat","lbs_state",b"lbs_state","lng",b"lng","offset",b"offset","page_size",b"page_size","player_args",b"player_args","qn",b"qn","refresh_city",b"refresh_city","teenagers_mode",b"teenagers_mode"]) -> None: ...
global___DynOurCityReq = DynOurCityReq

class ExpConf(google.protobuf.message.Message):
    """魔镜设置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXP_ENABLE_FIELD_NUMBER: builtins.int
    EXPS_FIELD_NUMBER: builtins.int
    exp_enable: builtins.int
    """是否是魔镜请求"""

    @property
    def exps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Exp]:
        """实验配置"""
        pass
    def __init__(self,
        *,
        exp_enable: builtins.int = ...,
        exps: typing.Optional[typing.Iterable[global___Exp]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exp_enable",b"exp_enable","exps",b"exps"]) -> None: ...
global___ExpConf = ExpConf

class Exp(google.protobuf.message.Message):
    """魔镜实验配置项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXP_NAME_FIELD_NUMBER: builtins.int
    EXP_GROUP_FIELD_NUMBER: builtins.int
    exp_name: typing.Text
    """实验名"""

    exp_group: typing.Text
    """实验组"""

    def __init__(self,
        *,
        exp_name: typing.Text = ...,
        exp_group: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exp_group",b"exp_group","exp_name",b"exp_name"]) -> None: ...
global___Exp = Exp

class DynOurCityReply(google.protobuf.message.Message):
    """动态同城-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    TOP_LABEL_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    TOP_BUTTON_LABEL_FIELD_NUMBER: builtins.int
    CITY_ID_FIELD_NUMBER: builtins.int
    CITY_NAME_FIELD_NUMBER: builtins.int
    offset: typing.Text
    """翻页游标"""

    has_more: builtins.int
    """是否还有更多数据
    1:有
    """

    style: builtins.int
    """样式类型
    1:双列 2:瀑布流
    """

    top_label: typing.Text
    """顶导信息"""

    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynOurCityItem]:
        """列表详情"""
        pass
    top_button_label: typing.Text
    """顶导按钮信息"""

    city_id: builtins.int
    """城市ID"""

    city_name: typing.Text
    """城市名"""

    def __init__(self,
        *,
        offset: typing.Text = ...,
        has_more: builtins.int = ...,
        style: builtins.int = ...,
        top_label: typing.Text = ...,
        list: typing.Optional[typing.Iterable[global___DynOurCityItem]] = ...,
        top_button_label: typing.Text = ...,
        city_id: builtins.int = ...,
        city_name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["city_id",b"city_id","city_name",b"city_name","has_more",b"has_more","list",b"list","offset",b"offset","style",b"style","top_button_label",b"top_button_label","top_label",b"top_label"]) -> None: ...
global___DynOurCityReply = DynOurCityReply

class DynOurCityItem(google.protobuf.message.Message):
    """动态同城物料"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CARD_TYPE_FIELD_NUMBER: builtins.int
    DYN_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    MODULES_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    DEBUG_INFO_FIELD_NUMBER: builtins.int
    card_type: typing.Text
    """卡片类型
    av:稿件 draw:图文
    """

    dyn_id: builtins.int
    """动态ID"""

    uri: typing.Text
    """跳转地址"""

    @property
    def modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynOurCityModule]:
        """模块列表"""
        pass
    rid: builtins.int
    """资源ID"""

    debug_info: typing.Text
    """透传服务端魔镜参数"""

    def __init__(self,
        *,
        card_type: typing.Text = ...,
        dyn_id: builtins.int = ...,
        uri: typing.Text = ...,
        modules: typing.Optional[typing.Iterable[global___DynOurCityModule]] = ...,
        rid: builtins.int = ...,
        debug_info: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["card_type",b"card_type","debug_info",b"debug_info","dyn_id",b"dyn_id","modules",b"modules","rid",b"rid","uri",b"uri"]) -> None: ...
global___DynOurCityItem = DynOurCityItem

class DynOurCityModule(google.protobuf.message.Message):
    """动态同城物料模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_TYPE_FIELD_NUMBER: builtins.int
    MODULE_COVER_FIELD_NUMBER: builtins.int
    MODULE_DESC_FIELD_NUMBER: builtins.int
    MODULE_AUTHOR_FIELD_NUMBER: builtins.int
    MODULE_EXTEND_FIELD_NUMBER: builtins.int
    module_type: typing.Text
    """类型
    cover:封面 desc:描述 author:发布人 extend:扩展部分
    """

    @property
    def module_cover(self) -> global___DynOurCityModuleCover:
        """封面"""
        pass
    @property
    def module_desc(self) -> global___DynOurCityModuleDesc:
        """描述"""
        pass
    @property
    def module_author(self) -> global___DynOurCityModuleAuthor:
        """发布人"""
        pass
    @property
    def module_extend(self) -> global___DynOurCityModuleExtend:
        """扩展部分"""
        pass
    def __init__(self,
        *,
        module_type: typing.Text = ...,
        module_cover: typing.Optional[global___DynOurCityModuleCover] = ...,
        module_desc: typing.Optional[global___DynOurCityModuleDesc] = ...,
        module_author: typing.Optional[global___DynOurCityModuleAuthor] = ...,
        module_extend: typing.Optional[global___DynOurCityModuleExtend] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["module_author",b"module_author","module_cover",b"module_cover","module_desc",b"module_desc","module_extend",b"module_extend","module_item",b"module_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["module_author",b"module_author","module_cover",b"module_cover","module_desc",b"module_desc","module_extend",b"module_extend","module_item",b"module_item","module_type",b"module_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["module_item",b"module_item"]) -> typing.Optional[typing_extensions.Literal["module_cover","module_desc","module_author","module_extend"]]: ...
global___DynOurCityModule = DynOurCityModule

class DynOurCityModuleCover(google.protobuf.message.Message):
    """动态同城物料-封面模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COVERS_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_1_FIELD_NUMBER: builtins.int
    COVER_LEFT_ICON_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_2_FIELD_NUMBER: builtins.int
    COVER_LEFT_TEXT_3_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    @property
    def covers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """封面图 单图样式取第一个元素"""
        pass
    style: builtins.int
    """封面样式
    1:横图 2:竖图 3:方图
    """

    cover_left_icon_1: builtins.int
    """视频封面展示项图标 1"""

    cover_left_text_1: typing.Text
    """视频封面展示项 1"""

    cover_left_icon_2: builtins.int
    """视频封面展示项图标 2"""

    cover_left_text_2: typing.Text
    """视频封面展示项 2"""

    cover_left_text_3: typing.Text
    """封面视频展示项 3"""

    @property
    def badge(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoBadge]:
        """角标"""
        pass
    def __init__(self,
        *,
        covers: typing.Optional[typing.Iterable[typing.Text]] = ...,
        style: builtins.int = ...,
        cover_left_icon_1: builtins.int = ...,
        cover_left_text_1: typing.Text = ...,
        cover_left_icon_2: builtins.int = ...,
        cover_left_text_2: typing.Text = ...,
        cover_left_text_3: typing.Text = ...,
        badge: typing.Optional[typing.Iterable[global___VideoBadge]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge",b"badge","cover_left_icon_1",b"cover_left_icon_1","cover_left_icon_2",b"cover_left_icon_2","cover_left_text_1",b"cover_left_text_1","cover_left_text_2",b"cover_left_text_2","cover_left_text_3",b"cover_left_text_3","covers",b"covers","style",b"style"]) -> None: ...
global___DynOurCityModuleCover = DynOurCityModuleCover

class DynOurCityModuleDesc(google.protobuf.message.Message):
    """动态同城物料-描述模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DESC_FIELD_NUMBER: builtins.int
    desc: typing.Text
    """描述信息"""

    def __init__(self,
        *,
        desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc"]) -> None: ...
global___DynOurCityModuleDesc = DynOurCityModuleDesc

class DynOurCityModuleAuthor(google.protobuf.message.Message):
    """动态同城物料-发布人模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户Mid"""

    name: typing.Text
    """用户昵称"""

    face: typing.Text
    """用户头像"""

    uri: typing.Text
    """跳转地址"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","mid",b"mid","name",b"name","uri",b"uri"]) -> None: ...
global___DynOurCityModuleAuthor = DynOurCityModuleAuthor

class DynOurCityModuleExtend(google.protobuf.message.Message):
    """动态同城物料-扩展部分模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    EXTEND_LBS_FIELD_NUMBER: builtins.int
    type: typing.Text
    """类型"""

    @property
    def extend_lbs(self) -> global___DynOurCityModuleExtendLBS:
        """LBS模块"""
        pass
    def __init__(self,
        *,
        type: typing.Text = ...,
        extend_lbs: typing.Optional[global___DynOurCityModuleExtendLBS] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extend",b"extend","extend_lbs",b"extend_lbs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["extend",b"extend","extend_lbs",b"extend_lbs","type",b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["extend",b"extend"]) -> typing.Optional[typing_extensions.Literal["extend_lbs"]]: ...
global___DynOurCityModuleExtend = DynOurCityModuleExtend

class DynOurCityModuleExtendLBS(google.protobuf.message.Message):
    """动态同城物料extent-LBS模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    POI_TYPE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    uri: typing.Text
    """跳转地址"""

    icon: typing.Text
    """小图标"""

    poi_type: builtins.int
    """poiType"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        icon: typing.Text = ...,
        poi_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","poi_type",b"poi_type","title",b"title","uri",b"uri"]) -> None: ...
global___DynOurCityModuleExtendLBS = DynOurCityModuleExtendLBS

class ModuleDynUpList(google.protobuf.message.Message):
    """最近访问up主列表"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODULE_TITLE_FIELD_NUMBER: builtins.int
    SHOW_ALL_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    module_title: typing.Text
    """标题展示文案"""

    show_all: typing.Text
    """“全部”按钮文案"""

    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpListItem]:
        """up主列表"""
        pass
    def __init__(self,
        *,
        module_title: typing.Text = ...,
        show_all: typing.Text = ...,
        list: typing.Optional[typing.Iterable[global___UpListItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list",b"list","module_title",b"module_title","show_all",b"show_all"]) -> None: ...
global___ModuleDynUpList = ModuleDynUpList

class UpListItem(google.protobuf.message.Message):
    """up主列表"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HAS_UPDATE_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    has_update: builtins.int
    """是否有更新
    0:没有 1:有
    """

    face: typing.Text
    """up主头像"""

    name: typing.Text
    """up主昵称"""

    uid: builtins.int
    """up主uid"""

    def __init__(self,
        *,
        has_update: builtins.int = ...,
        face: typing.Text = ...,
        name: typing.Text = ...,
        uid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","has_update",b"has_update","name",b"name","uid",b"uid"]) -> None: ...
global___UpListItem = UpListItem

class ModuleFollowList(google.protobuf.message.Message):
    """我的追番列表"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VIEW_ALL_LINK_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    view_all_link: typing.Text
    """查看全部的跳转链接"""

    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FollowListItem]:
        """"""
        pass
    def __init__(self,
        *,
        view_all_link: typing.Text = ...,
        list: typing.Optional[typing.Iterable[global___FollowListItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list",b"list","view_all_link",b"view_all_link"]) -> None: ...
global___ModuleFollowList = ModuleFollowList

class FollowListItem(google.protobuf.message.Message):
    """我的追番列表Item"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    NEW_EP_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """season_id"""

    title: typing.Text
    """标题"""

    cover: typing.Text
    """封面图"""

    url: typing.Text
    """跳转链接"""

    @property
    def new_ep(self) -> global___NewEP:
        """最新ep"""
        pass
    def __init__(self,
        *,
        season_id: builtins.int = ...,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        url: typing.Text = ...,
        new_ep: typing.Optional[global___NewEP] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["new_ep",b"new_ep"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","new_ep",b"new_ep","season_id",b"season_id","title",b"title","url",b"url"]) -> None: ...
global___FollowListItem = FollowListItem

class NewEP(google.protobuf.message.Message):
    """最新ep"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    INDEX_SHOW_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    id: builtins.int
    """最新话epid"""

    index_show: typing.Text
    """更新至XX话"""

    cover: typing.Text
    """更新剧集的封面"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        index_show: typing.Text = ...,
        cover: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","id",b"id","index_show",b"index_show"]) -> None: ...
global___NewEP = NewEP

class DynVideoPersonalReq(google.protobuf.message.Message):
    """最近访问-个人feed流列表-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    HOST_UID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    IS_PRELOAD_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    teenagers_mode: builtins.int
    """青少年模式
    1:开启青少年模式
    """

    host_uid: builtins.int
    """被访问者的mid"""

    offset: typing.Text
    """偏移量 第一页可传空"""

    page: builtins.int
    """标明下拉几次"""

    is_preload: builtins.int
    """是否是预加载"""

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """流版本"""

    fnval: builtins.int
    """流类型"""

    force_host: builtins.int
    """是否强制使用域名"""

    fourk: builtins.int
    """是否4k"""

    def __init__(self,
        *,
        teenagers_mode: builtins.int = ...,
        host_uid: builtins.int = ...,
        offset: typing.Text = ...,
        page: builtins.int = ...,
        is_preload: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","host_uid",b"host_uid","is_preload",b"is_preload","offset",b"offset","page",b"page","qn",b"qn","teenagers_mode",b"teenagers_mode"]) -> None: ...
global___DynVideoPersonalReq = DynVideoPersonalReq

class DynVideoPersonalReply(google.protobuf.message.Message):
    """最近访问-个人feed流列表-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIST_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    HAS_MORE_FIELD_NUMBER: builtins.int
    READ_OFFSET_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynamicItem]:
        """动态列表"""
        pass
    offset: typing.Text
    """偏移量"""

    has_more: builtins.int
    """是否还有更多数据"""

    read_offset: typing.Text
    """已读进度"""

    def __init__(self,
        *,
        list: typing.Optional[typing.Iterable[global___DynamicItem]] = ...,
        offset: typing.Text = ...,
        has_more: builtins.int = ...,
        read_offset: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_more",b"has_more","list",b"list","offset",b"offset","read_offset",b"read_offset"]) -> None: ...
global___DynVideoPersonalReply = DynVideoPersonalReply

class DynUpdOffsetReq(google.protobuf.message.Message):
    """最近访问-标记已读-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HOST_UID_FIELD_NUMBER: builtins.int
    READ_OFFSET_FIELD_NUMBER: builtins.int
    host_uid: builtins.int
    """被访问者的UID"""

    read_offset: typing.Text
    """用户已读进度"""

    def __init__(self,
        *,
        host_uid: builtins.int = ...,
        read_offset: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_uid",b"host_uid","read_offset",b"read_offset"]) -> None: ...
global___DynUpdOffsetReq = DynUpdOffsetReq

class PGCSeason(google.protobuf.message.Message):
    """PGC单季信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_FINISH_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    is_finish: builtins.int
    """是否完结"""

    title: typing.Text
    """标题"""

    type: builtins.int
    """类型"""

    def __init__(self,
        *,
        is_finish: builtins.int = ...,
        title: typing.Text = ...,
        type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_finish",b"is_finish","title",b"title","type",b"type"]) -> None: ...
global___PGCSeason = PGCSeason

class DynRedReq(google.protobuf.message.Message):
    """动态红点接口-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TAB_OFFSET_FIELD_NUMBER: builtins.int
    @property
    def tab_offset(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TabOffset]:
        """动态红点接口各tab offset信息"""
        pass
    def __init__(self,
        *,
        tab_offset: typing.Optional[typing.Iterable[global___TabOffset]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tab_offset",b"tab_offset"]) -> None: ...
global___DynRedReq = DynRedReq

class TabOffset(google.protobuf.message.Message):
    """动态红点接口各tab offset信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TAB_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    tab: builtins.int
    """1:综合页 2:视频页"""

    offset: typing.Text
    """上一次对应列表页offset"""

    def __init__(self,
        *,
        tab: builtins.int = ...,
        offset: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["offset",b"offset","tab",b"tab"]) -> None: ...
global___TabOffset = TabOffset

class DynRedReply(google.protobuf.message.Message):
    """红点接口-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RED_TYPE_FIELD_NUMBER: builtins.int
    DYN_RED_ITEM_FIELD_NUMBER: builtins.int
    DEFAULT_TAB_FIELD_NUMBER: builtins.int
    red_type: typing.Text
    """类型
    count:数字红点 point:普通红点 no_point:没有红点
    """

    @property
    def dyn_red_item(self) -> global___DynRedItem:
        """红点具体信息"""
        pass
    default_tab: typing.Text
    """默认tab 值对应tab接口下发的anchor"""

    def __init__(self,
        *,
        red_type: typing.Text = ...,
        dyn_red_item: typing.Optional[global___DynRedItem] = ...,
        default_tab: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dyn_red_item",b"dyn_red_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_tab",b"default_tab","dyn_red_item",b"dyn_red_item","red_type",b"red_type"]) -> None: ...
global___DynRedReply = DynRedReply

class DynRedItem(google.protobuf.message.Message):
    """红点接口物料"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COUNT_FIELD_NUMBER: builtins.int
    count: builtins.int
    """数字红点有效 更新数"""

    def __init__(self,
        *,
        count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count",b"count"]) -> None: ...
global___DynRedItem = DynRedItem

class MixUpListLiveItem(google.protobuf.message.Message):
    """直播信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    status: builtins.bool
    """直播状态
    0:未直播 1:直播中
    """

    room_id: builtins.int
    """房间号"""

    uri: typing.Text
    """跳转地址"""

    def __init__(self,
        *,
        status: builtins.bool = ...,
        room_id: builtins.int = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["room_id",b"room_id","status",b"status","uri",b"uri"]) -> None: ...
global___MixUpListLiveItem = MixUpListLiveItem

class MixUpListItem(google.protobuf.message.Message):
    """查看更多-列表单条数据"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    SPECIAL_ATTENTION_FIELD_NUMBER: builtins.int
    REDDOT_STATE_FIELD_NUMBER: builtins.int
    LIVE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    OFFICIAL_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户mid"""

    special_attention: builtins.int
    """特别关注
    0:否 1:是
    """

    reddot_state: builtins.int
    """小红点状态
    0:没有 1:有
    """

    @property
    def live_info(self) -> global___MixUpListLiveItem:
        """直播信息"""
        pass
    name: typing.Text
    """昵称"""

    face: typing.Text
    """头像"""

    @property
    def official(self) -> global___OfficialVerify:
        """认证信息"""
        pass
    @property
    def vip(self) -> global___VipInfo:
        """大会员信息"""
        pass
    @property
    def relation(self) -> global___Relation:
        """关注状态"""
        pass
    def __init__(self,
        *,
        uid: builtins.int = ...,
        special_attention: builtins.int = ...,
        reddot_state: builtins.int = ...,
        live_info: typing.Optional[global___MixUpListLiveItem] = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        official: typing.Optional[global___OfficialVerify] = ...,
        vip: typing.Optional[global___VipInfo] = ...,
        relation: typing.Optional[global___Relation] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["live_info",b"live_info","official",b"official","relation",b"relation","vip",b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","live_info",b"live_info","name",b"name","official",b"official","reddot_state",b"reddot_state","relation",b"relation","special_attention",b"special_attention","uid",b"uid","vip",b"vip"]) -> None: ...
global___MixUpListItem = MixUpListItem

class DynMixUpListViewMoreReply(google.protobuf.message.Message):
    """查看更多-列表-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMS_FIELD_NUMBER: builtins.int
    SEARCH_DEFAULT_TEXT_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MixUpListItem]:
        """关注up主列表信息"""
        pass
    search_default_text: typing.Text
    """默认搜索文案"""

    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___MixUpListItem]] = ...,
        search_default_text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items",b"items","search_default_text",b"search_default_text"]) -> None: ...
global___DynMixUpListViewMoreReply = DynMixUpListViewMoreReply

class DynMixUpListSearchReq(google.protobuf.message.Message):
    """查看更多-搜索-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name"]) -> None: ...
global___DynMixUpListSearchReq = DynMixUpListSearchReq

class DynMixUpListSearchReply(google.protobuf.message.Message):
    """查看更多-搜索-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MixUpListItem]:
        """"""
        pass
    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___MixUpListItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items",b"items"]) -> None: ...
global___DynMixUpListSearchReply = DynMixUpListSearchReply

class Relation(google.protobuf.message.Message):
    """关注关系"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_FOLLOWED_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    status: global___RelationStatus.ValueType
    """关注状态"""

    is_follow: builtins.int
    """关注"""

    is_followed: builtins.int
    """被关注"""

    title: typing.Text
    """文案"""

    def __init__(self,
        *,
        status: global___RelationStatus.ValueType = ...,
        is_follow: builtins.int = ...,
        is_followed: builtins.int = ...,
        title: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow",b"is_follow","is_followed",b"is_followed","status",b"status","title",b"title"]) -> None: ...
global___Relation = Relation

class OurCityClickReportReq(google.protobuf.message.Message):
    """动态同城点击上报-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DYNAMIC_ID_FIELD_NUMBER: builtins.int
    CITY_ID_FIELD_NUMBER: builtins.int
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    dynamic_id: typing.Text
    """动态ID"""

    city_id: builtins.int
    """城市ID"""

    lat: builtins.float
    """纬度"""

    lng: builtins.float
    """经度"""

    def __init__(self,
        *,
        dynamic_id: typing.Text = ...,
        city_id: builtins.int = ...,
        lat: builtins.float = ...,
        lng: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["city_id",b"city_id","dynamic_id",b"dynamic_id","lat",b"lat","lng",b"lng"]) -> None: ...
global___OurCityClickReportReq = OurCityClickReportReq

class OurCityClickReportReply(google.protobuf.message.Message):
    """动态同城点击上报-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___OurCityClickReportReply = OurCityClickReportReply

class GeoCoderReq(google.protobuf.message.Message):
    """位置定位-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    lat: builtins.float
    """纬度"""

    lng: builtins.float
    """经度"""

    def __init__(self,
        *,
        lat: builtins.float = ...,
        lng: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from",b"from","lat",b"lat","lng",b"lng"]) -> None: ...
global___GeoCoderReq = GeoCoderReq

class GeoCoderReply(google.protobuf.message.Message):
    """位置定位-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    ADDRESS_COMPONENT_FIELD_NUMBER: builtins.int
    AD_INFO_FIELD_NUMBER: builtins.int
    address: typing.Text
    """以行政区划+道路+门牌号等信息组成的标准格式化地址"""

    @property
    def address_component(self) -> global___AddressComponent:
        """地址部件，address不满足需求时可自行拼接"""
        pass
    @property
    def ad_info(self) -> global___AdInfo:
        """行政区划信息"""
        pass
    def __init__(self,
        *,
        address: typing.Text = ...,
        address_component: typing.Optional[global___AddressComponent] = ...,
        ad_info: typing.Optional[global___AdInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ad_info",b"ad_info","address_component",b"address_component"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_info",b"ad_info","address",b"address","address_component",b"address_component"]) -> None: ...
global___GeoCoderReply = GeoCoderReply

class AddressComponent(google.protobuf.message.Message):
    """地址部件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NATION_FIELD_NUMBER: builtins.int
    PROVINCE_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    DISTRICT_FIELD_NUMBER: builtins.int
    STREET_FIELD_NUMBER: builtins.int
    STREET_NUMBER_FIELD_NUMBER: builtins.int
    nation: typing.Text
    """国家"""

    province: typing.Text
    """省"""

    city: typing.Text
    """市"""

    district: typing.Text
    """区，可能为空字串"""

    street: typing.Text
    """街道，可能为空字串"""

    street_number: typing.Text
    """门牌，可能为空字串"""

    def __init__(self,
        *,
        nation: typing.Text = ...,
        province: typing.Text = ...,
        city: typing.Text = ...,
        district: typing.Text = ...,
        street: typing.Text = ...,
        street_number: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["city",b"city","district",b"district","nation",b"nation","province",b"province","street",b"street","street_number",b"street_number"]) -> None: ...
global___AddressComponent = AddressComponent

class AdInfo(google.protobuf.message.Message):
    """行政区划信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NATION_CODE_FIELD_NUMBER: builtins.int
    ADCODE_FIELD_NUMBER: builtins.int
    CITY_CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    GPS_FIELD_NUMBER: builtins.int
    nation_code: typing.Text
    """国家代码(ISO3166标准3位数字码)"""

    adcode: typing.Text
    """行政区划代码，规则详见：行政区划代码说明"""

    city_code: typing.Text
    """城市代码，由国家码+行政区划代码(提出城市级别)组合而来，总共为9位"""

    name: typing.Text
    """行政区划名称"""

    @property
    def gps(self) -> global___Gps:
        """行政区划中心点坐标"""
        pass
    def __init__(self,
        *,
        nation_code: typing.Text = ...,
        adcode: typing.Text = ...,
        city_code: typing.Text = ...,
        name: typing.Text = ...,
        gps: typing.Optional[global___Gps] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gps",b"gps"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["adcode",b"adcode","city_code",b"city_code","gps",b"gps","name",b"name","nation_code",b"nation_code"]) -> None: ...
global___AdInfo = AdInfo

class Gps(google.protobuf.message.Message):
    """行政区划中心点坐标"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    lat: builtins.float
    """纬度"""

    lng: builtins.float
    """经度"""

    def __init__(self,
        *,
        lat: builtins.float = ...,
        lng: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lat",b"lat","lng",b"lng"]) -> None: ...
global___Gps = Gps



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.main.common.arch.doll.v1 import doll_pb2 as bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2


class EchoStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/bilibili.main.common.arch.doll.v1.Echo/Ping',
                request_serializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.PingRequest.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.PingResponse.FromString,
                )
        self.Say = channel.unary_unary(
                '/bilibili.main.common.arch.doll.v1.Echo/Say',
                request_serializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.SayRequest.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.SayResponse.FromString,
                )
        self.Error = channel.unary_unary(
                '/bilibili.main.common.arch.doll.v1.Echo/Error',
                request_serializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.ErrorRequest.SerializeToString,
                response_deserializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.ErrorResponse.FromString,
                )


class EchoServicer(object):
    """
    """

    def Ping(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Say(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Error(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EchoServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.PingRequest.FromString,
                    response_serializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.PingResponse.SerializeToString,
            ),
            'Say': grpc.unary_unary_rpc_method_handler(
                    servicer.Say,
                    request_deserializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.SayRequest.FromString,
                    response_serializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.SayResponse.SerializeToString,
            ),
            'Error': grpc.unary_unary_rpc_method_handler(
                    servicer.Error,
                    request_deserializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.ErrorRequest.FromString,
                    response_serializer=bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.ErrorResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.main.common.arch.doll.v1.Echo', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Echo(object):
    """
    """

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.common.arch.doll.v1.Echo/Ping',
            bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.PingRequest.SerializeToString,
            bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.PingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Say(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.common.arch.doll.v1.Echo/Say',
            bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.SayRequest.SerializeToString,
            bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.SayResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Error(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.main.common.arch.doll.v1.Echo/Error',
            bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.ErrorRequest.SerializeToString,
            bilibili_dot_main_dot_common_dot_arch_dot_doll_dot_v1_dot_doll__pb2.ErrorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/gaia/gw/gw_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x62ilibili/gaia/gw/gw_api.proto\x12\x10\x62ilibili.gaia.gw\x1a\x1bgoogle/protobuf/empty.proto\"O\n\rDeviceAppList\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x17\n\x0fsystem_app_list\x18\x02 \x03(\t\x12\x15\n\ruser_app_list\x18\x03 \x03(\t\"L\n\x13\x46\x65tchPublicKeyReply\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65\x61\x64line\x18\x03 \x01(\x03\"\xe7\x02\n\x13GaiaDeviceBasicInfo\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\t\x12\x10\n\x08mobi_app\x18\x03 \x01(\t\x12\x0e\n\x06origin\x18\x04 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x05 \x01(\t\x12\x0e\n\x06sdkver\x18\x06 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x07 \x01(\t\x12\x18\n\x10\x61pp_version_code\x18\x08 \x01(\t\x12\r\n\x05\x62uild\x18\t \x01(\t\x12\x0f\n\x07\x63hannel\x18\n \x01(\t\x12\r\n\x05\x62rand\x18\x0b \x01(\t\x12\r\n\x05model\x18\x0c \x01(\t\x12\r\n\x05osver\x18\r \x01(\t\x12\x12\n\nuser_agent\x18\x0e \x01(\t\x12\x13\n\x0b\x62uvid_local\x18\x0f \x01(\t\x12\r\n\x05\x62uvid\x18\x10 \x01(\t\x12\x0b\n\x03mid\x18\x11 \x01(\t\x12\x0b\n\x03\x66ts\x18\x12 \x01(\x03\x12\r\n\x05\x66irst\x18\x13 \x01(\x05\x12\x0f\n\x07network\x18\x14 \x01(\t\"]\n\x11GaiaEncryptMsgReq\x12/\n\x06header\x18\x01 \x01(\x0b\x32\x1f.bilibili.gaia.gw.GaiaMsgHeader\x12\x17\n\x0f\x65ncrypt_payload\x18\x02 \x01(\x0c\"\x9d\x01\n\rGaiaMsgHeader\x12\x32\n\x0b\x65ncode_type\x18\x01 \x01(\x0e\x32\x1d.bilibili.gaia.gw.EncryptType\x12\x33\n\x0cpayload_type\x18\x02 \x01(\x0e\x32\x1d.bilibili.gaia.gw.PayloadType\x12\x17\n\x0f\x65ncoded_aes_key\x18\x03 \x01(\x0c\x12\n\n\x02ts\x18\x04 \x01(\x03\"&\n\x12UploadAppListReply\x12\x10\n\x08trace_id\x18\x01 \x01(\t*K\n\x0b\x45ncryptType\x12\x18\n\x14INVALID_ENCRYPT_TYPE\x10\x00\x12\x0e\n\nCLIENT_AES\x10\x01\x12\x12\n\x0eSERVER_RSA_AES\x10\x02*7\n\x0bPayloadType\x12\x13\n\x0fINVALID_PAYLOAD\x10\x00\x12\x13\n\x0f\x44\x45VICE_APP_LIST\x10\x01\x32\xb7\x01\n\x04Gaia\x12\\\n\x0f\x45xUploadAppList\x12#.bilibili.gaia.gw.GaiaEncryptMsgReq\x1a$.bilibili.gaia.gw.UploadAppListReply\x12Q\n\x10\x45xFetchPublicKey\x12\x16.google.protobuf.Empty\x1a%.bilibili.gaia.gw.FetchPublicKeyReplyb\x06proto3')

_ENCRYPTTYPE = DESCRIPTOR.enum_types_by_name['EncryptType']
EncryptType = enum_type_wrapper.EnumTypeWrapper(_ENCRYPTTYPE)
_PAYLOADTYPE = DESCRIPTOR.enum_types_by_name['PayloadType']
PayloadType = enum_type_wrapper.EnumTypeWrapper(_PAYLOADTYPE)
INVALID_ENCRYPT_TYPE = 0
CLIENT_AES = 1
SERVER_RSA_AES = 2
INVALID_PAYLOAD = 0
DEVICE_APP_LIST = 1


_DEVICEAPPLIST = DESCRIPTOR.message_types_by_name['DeviceAppList']
_FETCHPUBLICKEYREPLY = DESCRIPTOR.message_types_by_name['FetchPublicKeyReply']
_GAIADEVICEBASICINFO = DESCRIPTOR.message_types_by_name['GaiaDeviceBasicInfo']
_GAIAENCRYPTMSGREQ = DESCRIPTOR.message_types_by_name['GaiaEncryptMsgReq']
_GAIAMSGHEADER = DESCRIPTOR.message_types_by_name['GaiaMsgHeader']
_UPLOADAPPLISTREPLY = DESCRIPTOR.message_types_by_name['UploadAppListReply']
DeviceAppList = _reflection.GeneratedProtocolMessageType('DeviceAppList', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEAPPLIST,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.DeviceAppList)
  })
_sym_db.RegisterMessage(DeviceAppList)

FetchPublicKeyReply = _reflection.GeneratedProtocolMessageType('FetchPublicKeyReply', (_message.Message,), {
  'DESCRIPTOR' : _FETCHPUBLICKEYREPLY,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.FetchPublicKeyReply)
  })
_sym_db.RegisterMessage(FetchPublicKeyReply)

GaiaDeviceBasicInfo = _reflection.GeneratedProtocolMessageType('GaiaDeviceBasicInfo', (_message.Message,), {
  'DESCRIPTOR' : _GAIADEVICEBASICINFO,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.GaiaDeviceBasicInfo)
  })
_sym_db.RegisterMessage(GaiaDeviceBasicInfo)

GaiaEncryptMsgReq = _reflection.GeneratedProtocolMessageType('GaiaEncryptMsgReq', (_message.Message,), {
  'DESCRIPTOR' : _GAIAENCRYPTMSGREQ,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.GaiaEncryptMsgReq)
  })
_sym_db.RegisterMessage(GaiaEncryptMsgReq)

GaiaMsgHeader = _reflection.GeneratedProtocolMessageType('GaiaMsgHeader', (_message.Message,), {
  'DESCRIPTOR' : _GAIAMSGHEADER,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.GaiaMsgHeader)
  })
_sym_db.RegisterMessage(GaiaMsgHeader)

UploadAppListReply = _reflection.GeneratedProtocolMessageType('UploadAppListReply', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADAPPLISTREPLY,
  '__module__' : 'bilibili.gaia.gw.gw_api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.gaia.gw.UploadAppListReply)
  })
_sym_db.RegisterMessage(UploadAppListReply)

_GAIA = DESCRIPTOR.services_by_name['Gaia']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENCRYPTTYPE._serialized_start=896
  _ENCRYPTTYPE._serialized_end=971
  _PAYLOADTYPE._serialized_start=973
  _PAYLOADTYPE._serialized_end=1028
  _DEVICEAPPLIST._serialized_start=80
  _DEVICEAPPLIST._serialized_end=159
  _FETCHPUBLICKEYREPLY._serialized_start=161
  _FETCHPUBLICKEYREPLY._serialized_end=237
  _GAIADEVICEBASICINFO._serialized_start=240
  _GAIADEVICEBASICINFO._serialized_end=599
  _GAIAENCRYPTMSGREQ._serialized_start=601
  _GAIAENCRYPTMSGREQ._serialized_end=694
  _GAIAMSGHEADER._serialized_start=697
  _GAIAMSGHEADER._serialized_end=854
  _UPLOADAPPLISTREPLY._serialized_start=856
  _UPLOADAPPLISTREPLY._serialized_end=894
  _GAIA._serialized_start=1031
  _GAIA._serialized_end=1214
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Sync(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NOTE_ID_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    note_id: builtins.int
    """笔记id"""

    hash: typing.Text
    """唯一标示"""

    def __init__(self,
        *,
        note_id: builtins.int = ...,
        hash: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash",b"hash","note_id",b"note_id"]) -> None: ...
global___Sync = Sync
